@@ -22,10 +22,8 @@ class AIOModelBase(ModelBase):
     def __new__(cls, name, bases, attrs):
         cls = super(AIOModelBase, cls).__new__(cls, name, bases, attrs)
         meta = cls._meta
-        if getattr(meta, 'manager', None):
-            meta.manager.models.add(cls)
-            if not meta.database:
-                meta.database = meta.manager.pw_database
+        if getattr(meta, 'manager', None) and not meta.database:
+            meta.database = meta.manager.pw_database
 
         return cls
 
@@ -69,7 +67,8 @@ class AIOModel(Model, metaclass=AIOModelBase):
 
     @classmethod
     async def create(cls, **kwargs) -> AIOModel:
-        return await cls._meta.manager.create(cls, **kwargs)
+        inst = cls(**kwargs)
+        return await inst.save(force_insert=True)
 
     # Queryset methods
     # ----------------
